<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data from the body
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['type']) || empty($data['id']) || empty($data['studentid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Type, ID, and studentid are required']);
        exit;
    }

    $type = $data['type'];
    $id = $data['id'];
    $studentId = $data['studentid'];
    $code = isset($data['code']) ? $data['code'] : null;

    try {
        $price = 0;

        // Determine if it's a module or subject and fetch the price
        if ($type === 'module') {
            $stmt = $con->prepare('SELECT price FROM modules WHERE id = ?');
            $stmt->execute([$id]);
            $module = $stmt->fetch(PDO::FETCH_ASSOC);

            if (!$module) {
                http_response_code(400); // Bad Request
                echo json_encode(['error' => 'Module not found']);
                exit;
            }
            $price = $module['price'];

        } elseif ($type === 'subject') {
            $stmt = $con->prepare('SELECT price FROM subjects WHERE id = ?');
            $stmt->execute([$id]);
            $subject = $stmt->fetch(PDO::FETCH_ASSOC);

            if (!$subject) {
                http_response_code(400); // Bad Request
                echo json_encode(['error' => 'Subject not found']);
                exit;
            }
            $price = $subject['price'];

        } else {
            http_response_code(400); // Bad Request
            echo json_encode(['error' => 'Invalid type']);
            exit;
        }

        // Validate code if provided
        $discount = 0;
        if ($code) {
            $stmt = $con->prepare('SELECT price FROM codes WHERE code = ? AND studentid = ?');
            $stmt->execute([$code, $studentId]);
            $codeData = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($codeData) {
                $discount = $codeData['price'];
            } else {
                http_response_code(400); // Bad Request
                echo json_encode(['error' => 'Invalid discount code']);
                exit;
            }
        }

        // Calculate the final price after applying the discount
        $finalPrice = max(0, $price - $discount);

        // Check if the student has enough balance if no code is provided or discount is not enough
        if ($finalPrice > 0) {
            $stmt = $con->prepare('SELECT SUM(money) AS balance FROM student_wallet WHERE studentid = ?');
            $stmt->execute([$studentId]);
            $balance = $stmt->fetch(PDO::FETCH_ASSOC)['balance'];

            if ($balance < $finalPrice) {
                http_response_code(400); // Bad Request
                echo json_encode(['error' => 'Insufficient funds']);
                exit;
            }

            // Deduct the amount from the student's wallet balance
            $stmt = $con->prepare('UPDATE student_wallet SET money = money - ? WHERE studentid = ?');
            $stmt->execute([$finalPrice, $studentId]);
        }

        // Insert the record into the appropriate table
        if ($type === 'module') {
            $stmt = $con->prepare('INSERT INTO modules_students (module_id, student_id, status) VALUES (?, ?, ?)');
            $stmt->execute([$id, $studentId, 1]);

        } elseif ($type === 'subject') {
            $stmt = $con->prepare('INSERT INTO studentssubjects (subjectid, studentid, approve) VALUES (?, ?, ?)');
            $stmt->execute([$id, $studentId, 1]);
        }

        // Success response
        echo json_encode(['success' => ucfirst($type) . ' successfully purchased']);

    } catch (Exception $e) {
        // Handle any errors
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Error processing the request', 'details' => $e->getMessage()]);
    }

} else {
    // Invalid request method
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
