<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['studentid']) || empty($data['assignmentid']) || empty($data['answers'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Missing required fields']);
        exit;
    }

    $studentId = $data['studentid'];
    $assignmentid = $data['assignmentid'];
    $answers = $data['answers'];

    try {
        // Begin a transaction
        $con->beginTransaction();

        $totalDegree = 0; // Initialize total degree

        foreach ($answers as $answer) {
            $questionId = $answer['questionid'];
            $choice = $answer['choice']; // This will be 1, 2, 3, or 4

            // Fetch the degree for the question
            $stmt = $con->prepare('SELECT degree FROM homeworkquestions WHERE homeworkid = ? AND questionid = ?');
            $stmt->execute([$assignmentid, $questionId]);
            $homework = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($homework === false) {
                throw new Exception('Homework not found');
            }

            $degree = $homework['degree'];

            // Fetch the correct answer from the questions table
            $stmt = $con->prepare('SELECT answer FROM questions WHERE id = ?');
            $stmt->execute([$questionId]);
            $question = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($question === false) {
                throw new Exception('Question not found');
            }

            // Get the correct answer (1-4)
            $correctAnswer = $question['answer'];

            // Check if the selected choice is correct
            $isCorrect = ($choice == $correctAnswer);

            // Only accumulate total degree if the answer is correct
            if ($isCorrect) {
                $totalDegree += $degree;
            }

            // Insert the answer into the new_homework_answers table
            $stmt = $con->prepare('INSERT INTO new_homework_answers (studentid, questionid, homeworkid, answer, degree) VALUES (?, ?, ?, ?, ?)');
            $stmt->execute([$studentId, $questionId, $assignmentid, $choice, $degree]);
        }

        // Insert into studenthw table
        $endTime = date('Y-m-d H:i:s'); // Get current timestamp
        $stmt = $con->prepare('INSERT INTO studenthw (studentid, homeworkid, result) VALUES (?, ?, ?)');
        $stmt->execute([$studentId, $assignmentid, $totalDegree]);

        // Commit the transaction
        $con->commit();

        // Prepare success response
        $response = ['success' => 'Answers submitted successfully', 'totalDegree' => $totalDegree];
        echo json_encode($response);

    } catch (Exception $e) {
        // Rollback the transaction if there is an error
        $con->rollBack();
        
        // Prepare error response
        http_response_code(500); // Internal Server Error
        $response = ['error' => 'Failed to submit answers', 'details' => $e->getMessage()];
        echo json_encode($response);
    }

} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Method Not Allowed']);
}
?>
