<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Get the userid and chapterid from the query parameters
    $userid = isset($_GET['userid']) ? intval($_GET['userid']) : 0;
    $chapterId = isset($_GET['chapterid']) ? intval($_GET['chapterid']) : 0;

    if ($userid == 0 || $chapterId == 0) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Invalid or missing userid or chapterid']);
        exit;
    }

    try {
        // Fetch the subject ids for the given userid
        $stmt = $con->prepare('SELECT subjectid FROM studentssubjects WHERE studentid = ?');
        $stmt->execute([$userid]);
        $subjectIds = $stmt->fetchAll(PDO::FETCH_COLUMN, 0);

        if (empty($subjectIds)) {
            // If no subjects are found for the user
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'No subjects found for this student']);
            exit;
        }

        // Prepare queries for each content type filtering by chapterid and subjectid
        $queries = [
            'videos' => 'SELECT id, name, iframe FROM videos WHERE chapterid = ? AND subjectid IN (' . implode(',', array_fill(0, count($subjectIds), '?')) . ')',
            'quizzes' => 'SELECT exams.id, exams.name, exams.timer, (SELECT COUNT(*) FROM examquestions WHERE examquestions.examid = exams.id) AS number_of_questions 
                          FROM exams WHERE chapterid = ? AND subjectid IN (' . implode(',', array_fill(0, count($subjectIds), '?')) . ')',
            'assignments' => 'SELECT homeworks.id, homeworks.name, homeworks.enddate, (SELECT COUNT(*) FROM homeworkquestions WHERE homeworkquestions.homeworkid = homeworks.id) AS number_of_questions 
                              FROM homeworks WHERE chapterid = ? AND subjectid IN (' . implode(',', array_fill(0, count($subjectIds), '?')) . ')',
            'material' => 'SELECT id, name, file FROM files WHERE chapterid = ? AND subjectid IN (' . implode(',', array_fill(0, count($subjectIds), '?')) . ')'
        ];

        $results = [
            'videos' => [],
            'quizzes' => [],
            'assignments' => [],
            'material' => []
        ];

        // File path for materials
        $filePath = 'https://optima-software-solutions.com/falcon/dasboard/uploads/files/';

        // Execute each query and store results in the respective array
        foreach ($queries as $type => $query) {
            $stmt = $con->prepare($query);
            $params = array_merge([$chapterId], $subjectIds); // Add chapterid to the start of parameters
            $stmt->execute($params);
            $fetchedResults = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // Add completion status for assignments (homework) and quizzes (exams)
            foreach ($fetchedResults as &$result) {
                // Cast id to string
                $result['id'] = (string) $result['id'];

                if ($type === 'assignments') {
                    // Check if homework is completed in studenthw
                    $stmtCheck = $con->prepare('SELECT COUNT(*) FROM studenthw WHERE studentid = ? AND homeworkid = ?');
                    $stmtCheck->execute([$userid, $result['id']]);
                    $completed = $stmtCheck->fetchColumn() > 0 ? 1 : 0;
                    $result['completed'] = $completed;
                } elseif ($type === 'quizzes') {
                    // Check if exam is completed in studentexam
                    $stmtCheck = $con->prepare('SELECT COUNT(*) FROM studentexam WHERE studentid = ? AND examid = ?');
                    $stmtCheck->execute([$userid, $result['id']]);
                    $completed = $stmtCheck->fetchColumn() > 0 ? 1 : 0;
                    $result['completed'] = $completed;
                } elseif ($type === 'material') {
                    // Add full file path for material
                    $result['file'] = $filePath . $result['file'];
                }
            }

            $results[$type] = $fetchedResults;
        }

        // Return the structured results
        echo json_encode($results);
    } catch (Exception $e) {
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'An error occurred', 'error' => $e->getMessage()]);
    }
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
