<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Check if 'moduleid' is provided in the query parameters
    if (!isset($_GET['moduleid']) || empty($_GET['moduleid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Module ID parameter is missing or empty']);
        exit;
    }

    $moduleId = $_GET['moduleid'];
    $baseUrlSubjects = 'https://optima-software-solutions.com/falcon/dasboard/uploads/subjects/';
    $baseUrlDoctors = 'https://optima-software-solutions.com/falcon/dasboard/uploads/doctors/';

    try {
        // Fetch all subjects associated with the module ID
        $stmt = $con->prepare('SELECT s.id AS subject_id, s.name AS subject_name, s.price AS subject_price, s.description AS subject_description, s.image AS subject_image
            FROM subjects s WHERE s.module = ?');
        $stmt->execute([$moduleId]);
        $subjects = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (empty($subjects)) {
            // No subjects found for the module
            $response = [
                'message' => 'success',
                'subjects' => []
            ];
            echo json_encode($response);
            exit;
        }

        // Fetch doctor IDs associated with these subjects
        $subjectIds = array_column($subjects, 'subject_id');
        $placeholders = str_repeat('?,', count($subjectIds) - 1) . '?';
        $stmt = $con->prepare('SELECT sd.subject_id, sd.doctor_id FROM subjects_doctors sd 
        WHERE sd.subject_id IN (' . $placeholders . ')');
        $stmt->execute($subjectIds);
        $doctorAssociations = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch doctor names, phone numbers, descriptions, and images from the admin table
        $doctorIds = array_column($doctorAssociations, 'doctor_id');
        if (!empty($doctorIds)) {
            $placeholders = str_repeat('?,', count($doctorIds) - 1) . '?';
            $stmt = $con->prepare('SELECT id, name, phone, description AS doctor_description, image FROM admins
                WHERE id IN (' . $placeholders . ')');
            $stmt->execute($doctorIds);
            $doctors = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // Construct the image URLs and create an associative array of doctors
            $doctorDetails = [];
            foreach ($doctors as $doctor) {
                $doctorDetails[(string) $doctor['id']] = [
                    'name' => $doctor['name'],
                    'phone' => $doctor['phone'],
                    'description' => $doctor['doctor_description'],
                    'image_url' => !empty($doctor['image']) ? $baseUrlDoctors . $doctor['image'] : 'No image found'
                ];
            }
        } else {
            $doctorDetails = [];
        }

        // Attach doctor details to each subject
        foreach ($subjects as &$subject) {
            // Cast subject_id and subject_price to strings
            $subject['subject_id'] = (string) $subject['subject_id'];
            $subject['subject_price'] = (string) $subject['subject_price'];
            
            // Construct the full URL for the subject image
            $subject['subject_image_url'] = !empty($subject['subject_image']) ? $baseUrlSubjects . $subject['subject_image'] : 'No image found'; 
            $subject['doctors'] = []; // Initialize doctors array

            foreach ($doctorAssociations as $assoc) {
                if ($assoc['subject_id'] === $subject['subject_id']) {
                    $doctorId = (string) $assoc['doctor_id'];
                    $subject['doctors'][] = [
                        'id' => $doctorId,
                        'name' => $doctorDetails[$doctorId]['name'] ?? 'Unknown',
                        'phone' => $doctorDetails[$doctorId]['phone'] ?? 'No phone',
                        'description' => $doctorDetails[$doctorId]['description'] ?? 'No description',
                        'image_url' => $doctorDetails[$doctorId]['image_url'] ?? 'No image found'
                    ];
                }
            }

            // Remove the 'subject_image' field
            unset($subject['subject_image']);
        }

        // Prepare the response with success message
        $response = [
            'message' => 'success',
            'subjects' => $subjects
        ];
    } catch (Exception $e) {
        // In case of an error, return a failure message
        $response = [
            'message' => 'failure',
            'error' => $e->getMessage()
        ];
        http_response_code(500); // Internal Server Error
    }

    echo json_encode($response);
} else {
    // Invalid request method, return an error response
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
